@@ -125,6 +125,7 @@ class Session(QObject):
                 print('* Trying to attach to {0}'.format(args.pid))
                 try:
                     self.dwarf.attach(args.pid, args.script, False)
+                    print('* Dwarf attached to {0}'.format(args.pid))
                 except Exception as e:  # pylint: disable=broad-except
                     print('-failed-')
                     print('Reason: ' + str(e))
@@ -134,7 +135,8 @@ class Session(QObject):
             else:
                 print('* Trying to spawn {0}'.format(args.any))
                 try:
-                    self.dwarf.spawn(args.any, args=args.args, script=args.script)
+                    _pid = self.dwarf.spawn(args.any, args=args.args, script=args.script)
+                    print('* Dwarf attached to {0}'.format(_pid))
                 except Exception as e:  # pylint: disable=broad-except
                     print('-failed-')
                     print('Reason: ' + str(e))
